# -*- coding: utf-8 -*-

from __future__ import division

import os

from django.conf import settings
from django.core.files.storage import default_storage
from django_file_md5 import calculate_md5
from django_logit import logit
from django_response import response
from TimeConvert import TimeConvert as tc


@logit
def file_upload(request):
    # File Not Found
    if not request.FILES:
        return response(settings.FILE_NOT_FOUND if hasattr(settings, 'FILE_NOT_FOUND') else 999999)

    # File Object
    file_ = request.FILES.get('file', '')

    # File Ext
    ext = os.path.splitext(file_.name)[-1]

    # File Path
    base_path = settings.DJANGO_FILE_UPLOAD_BASE_PATH if hasattr(settings, 'DJANGO_FILE_UPLOAD_BASE_PATH') else 'file'
    ym_path = tc.local_string(format='%Y%m') if hasattr(settings, 'DJANGO_FILE_UPLOAD_USE_YM') and settings.DJANGO_FILE_UPLOAD_USE_YM else ''
    file_path = '{0}/{1}{2}{3}{4}'.format(base_path, ym_path, ym_path and '/', calculate_md5(file_), ext)

    # File Save
    if not default_storage.exists(file_path):
        default_storage.save(file_path, file_)

    return response(200, 'File Upload Success', u'文件上传成功', data={
        'file_path': file_path,
        'file_url': '{0}{1}'.format(settings.DOMAIN if hasattr(settings, 'DOMAIN') else '', default_storage.url(file_path)),
    })



# -*- coding: utf-8 -*-

from setuptools import setup


version = '1.0.2'


setup(
    name='django-file-upload',
    version=version,
    keywords='Django File Upload',
    description='Django File Upload',
    long_description=open('README.rst').read(),

    url='https://github.com/django-xxx/django-file-upload',

    author='Hackathon',
    author_email='kimi.huang@brightcells.com',

    packages=['django_file_upload'],
    py_modules=[],
    install_requires=['django-file-md5>=1.0.2', 'django_logit>=1.1.2', 'django-response'],

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Office/Business :: Financial :: Spreadsheet',
    ],
)
